@@ -3,8 +3,7 @@
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# the Free Software Foundation, version 3.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,6 +14,9 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 from kivy.resources import resource_add_path
 from . import calendar
+
 resource_add_path(__path__[0] + '/assets')
 
-__all__ = ['graph', 'app', 'card', 'dialog', 'game', 'spritebuilder', 'calendar']
\ No newline at end of file
+__all__ = [
+    'graph', 'app', 'card', 'dialog', 'game', 'spritebuilder', 'calendar'
+]
