@@ -3,8 +3,7 @@
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# the Free Software Foundation, version 3.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +13,13 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """Object to configure, start, and stop ELiDE."""
-
+import sys
+import os
 import json
 
+if 'KIVY_NO_ARGS' not in os.environ:
+    os.environ['KIVY_NO_ARGS'] = '1'
+
 from kivy.logger import Logger
 from kivy.app import App
 from kivy.clock import Clock
@@ -24,12 +27,8 @@ from kivy.resources import resource_add_path
 
 from kivy.uix.screenmanager import ScreenManager, NoTransition
 
-from kivy.properties import (
-    AliasProperty,
-    ObjectProperty,
-    NumericProperty,
-    StringProperty
-)
+from kivy.properties import (AliasProperty, BooleanProperty, ObjectProperty,
+                             NumericProperty, StringProperty)
 import LiSE
 from LiSE.proxy import EngineProcessManager, CharStatProxy
 import ELiDE
@@ -57,7 +56,7 @@ class ELiDEApp(App):
     """
     title = 'ELiDE'
 
-    engine = ObjectProperty()
+    engine = None
     branch = StringProperty('trunk')
     turn = NumericProperty(0)
     tick = NumericProperty(0)
@@ -66,6 +65,7 @@ class ELiDEApp(App):
     selected_proxy = ObjectProperty()
     selected_proxy_name = StringProperty('')
     statcfg = ObjectProperty()
+    edit_locked = BooleanProperty(False)
 
     def on_selection(self, *args):
         Logger.debug("App: {} selected".format(self.selection))
@@ -75,16 +75,22 @@ class ELiDEApp(App):
             self.selected_proxy_name = str(self.selected_proxy.name)
             return
         selected_proxy = self.selected_proxy
-        assert hasattr(selected_proxy, 'origin'), '{} has no origin'.format(type(selected_proxy))
-        assert hasattr(selected_proxy, 'destination'), '{} has no destination'.format(type(selected_proxy))
+        assert hasattr(selected_proxy, 'origin'), '{} has no origin'.format(
+            type(selected_proxy))
+        assert hasattr(selected_proxy,
+                       'destination'), '{} has no destination'.format(
+                           type(selected_proxy))
         origin = selected_proxy.origin
         destination = selected_proxy.destination
         reciprocal = selected_proxy.reciprocal
-        if selected_proxy.get('is_mirror', False) or (reciprocal and reciprocal.get('is_mirror', False)):
+        if selected_proxy.get(
+                'is_mirror',
+                False) or (reciprocal and reciprocal.get('is_mirror', False)):
             link = '<>'
         else:
             link = '->'
-        self.selected_proxy_name = str(origin.name) + link + str(destination.name)
+        self.selected_proxy_name = str(origin.name) + link + str(
+            destination.name)
 
     def _get_character_name(self, *args):
         if self.character is None:
@@ -95,11 +101,9 @@ class ELiDEApp(App):
         if self.character.name != name:
             self.character = self.engine.character[name]
 
-    character_name = AliasProperty(
-        _get_character_name,
-        _set_character_name,
-        bind=('character',)
-    )
+    character_name = AliasProperty(_get_character_name,
+                                   _set_character_name,
+                                   bind=('character', ))
 
     def _pull_time(self, *args):
         if not self.engine:
@@ -109,17 +113,21 @@ class ELiDEApp(App):
         self.branch = branch
         self.turn = turn
         self.tick = tick
+
     pull_time = trigger(_pull_time)
 
     @trigger
     def _push_time(self, *args):
+        if not self.engine:
+            return
         branch, turn, tick = self.engine._btt()
         if (self.branch, self.turn, self.tick) != (branch, turn, tick):
             self.engine.time_travel(
-                self.branch, self.turn, self.tick if self.tick != tick else None,
+                self.branch,
+                self.turn,
+                self.tick if self.tick != tick else None,
                 chars=[self.character.name],
-                cb=self.mainscreen._update_from_time_travel
-            )
+                cb=self.mainscreen._update_from_time_travel)
 
     def set_tick(self, t):
         """Set my tick to the given value, cast to an integer."""
@@ -143,62 +151,55 @@ class ELiDEApp(App):
         for sec in 'LiSE', 'ELiDE':
             config.adddefaultsection(sec)
         config.setdefaults(
-            'LiSE',
-            {
+            'LiSE', {
                 'world': 'sqlite:///world.db',
                 'language': 'eng',
                 'logfile': '',
                 'loglevel': 'info'
-            }
-        )
+            })
         config.setdefaults(
-            'ELiDE',
-            {
-                'debugger': 'no',
-                'inspector': 'no',
-                'user_kv': 'yes',
-                'play_speed': '1',
-                'thing_graphics': json.dumps([
-                    ('RLTiles: Body', 'base.atlas'),
-                    ('RLTiles: Basic clothes', 'body.atlas'),
-                    ('RLTiles: Armwear', 'arm.atlas'),
-                    ('RLTiles: Legwear', 'leg.atlas'),
-                    ('RLTiles: Right hand', 'hand1.atlas'),
-                    ('RLTiles: Left hand', 'hand2.atlas'),
-                    ('RLTiles: Boots', 'boot.atlas'),
-                    ('RLTiles: Hair', 'hair.atlas'),
-                    ('RLTiles: Beard', 'beard.atlas'),
-                    ('RLTiles: Headwear', 'head.atlas')
-                ]),
-                'place_graphics': json.dumps([
-                    ('RLTiles: Dungeon', 'dungeon.atlas'),
-                    ('RLTiles: Floor', 'floor.atlas')
-                ])
-            }
-        )
+            'ELiDE', {
+                'debugger':
+                'no',
+                'inspector':
+                'no',
+                'user_kv':
+                'yes',
+                'play_speed':
+                '1',
+                'thing_graphics':
+                json.dumps([('RLTiles: Body', 'base.atlas'),
+                            ('RLTiles: Basic clothes', 'body.atlas'),
+                            ('RLTiles: Armwear', 'arm.atlas'),
+                            ('RLTiles: Legwear', 'leg.atlas'),
+                            ('RLTiles: Right hand', 'hand1.atlas'),
+                            ('RLTiles: Left hand', 'hand2.atlas'),
+                            ('RLTiles: Boots', 'boot.atlas'),
+                            ('RLTiles: Hair', 'hair.atlas'),
+                            ('RLTiles: Beard', 'beard.atlas'),
+                            ('RLTiles: Headwear', 'head.atlas')]),
+                'place_graphics':
+                json.dumps([('RLTiles: Dungeon', 'dungeon.atlas'),
+                            ('RLTiles: Floor', 'floor.atlas')])
+            })
         config.write()
 
     def build(self):
         self.icon = 'icon_24px.png'
         config = self.config
-        Logger.debug(
-            "ELiDEApp: starting with world {}, path {}".format(
-                config['LiSE']['world'],
-                LiSE.__path__[-1]
-            )
-        )
+        Logger.debug("ELiDEApp: starting with world {}, path {}".format(
+            config['LiSE']['world'], LiSE.__path__[-1]))
 
         if config['ELiDE']['debugger'] == 'yes':
             import pdb
             pdb.set_trace()
 
-
         self.manager = ScreenManager(transition=NoTransition())
         if config['ELiDE']['inspector'] == 'yes':
             from kivy.core.window import Window
             from kivy.modules import inspector
             inspector.create_inspector(Window, self.manager)
-        
+
         self._add_screens()
         return self.manager
 
@@ -233,15 +234,14 @@ class ELiDEApp(App):
         self.engine.string.language.connect(self._pull_lang, weak=False)
         self.engine.character.connect(self._pull_chars, weak=False)
 
-        self.bind(
-            branch=self._push_time,
-            turn=self._push_time,
-            tick=self._push_time
-        )
+        self.bind(branch=self._push_time,
+                  turn=self._push_time,
+                  tick=self._push_time)
 
         self.strings.store = self.engine.string
         self._started = True
         return engine
+
     trigger_start_subprocess = trigger(start_subprocess)
 
     def init_board(self, *args):
@@ -252,19 +252,20 @@ class ELiDEApp(App):
         """
         if 'boardchar' not in self.engine.eternal:
             if 'physical' in self.engine.character:
-                self.engine.eternal['boardchar'] = self.engine.character['physical']
+                self.engine.eternal['boardchar'] = self.engine.character[
+                    'physical']
             else:
-                chara = self.engine.eternal['boardchar'] = self.engine.new_character('physical')
+                chara = self.engine.eternal[
+                    'boardchar'] = self.engine.new_character('physical')
         self.chars.names = list(self.engine.character)
         self.mainscreen.graphboards = {
-                name: GraphBoard(
-                    character=char
-                ) for name, char in self.engine.character.items()
-            }
+            name: GraphBoard(character=char)
+            for name, char in self.engine.character.items()
+        }
         self.mainscreen.gridboards = {
-                name: GridBoard(character=char)
-                for name, char in self.engine.character.items()
-            }
+            name: GridBoard(character=char)
+            for name, char in self.engine.character.items()
+        }
         self.select_character(self.engine.eternal['boardchar'])
         self.selected_proxy = self._get_selected_proxy()
 
@@ -275,46 +276,31 @@ class ELiDEApp(App):
                     self.manager.current = 'main'
                 else:
                     self.manager.current = screenname
+
             return tog
+
         config = self.config
 
-        self.mainmenu = ELiDE.menu.DirPicker(
-            toggle=toggler('mainmenu'),
-            start=self.start_subprocess
-        )
+        self.mainmenu = ELiDE.menu.DirPicker(toggle=toggler('mainmenu'))
 
         self.pawncfg = ELiDE.spritebuilder.PawnConfigScreen(
             toggle=toggler('pawncfg'),
-            data=json.loads(config['ELiDE']['thing_graphics'])
-        )
+            data=json.loads(config['ELiDE']['thing_graphics']))
 
         self.spotcfg = ELiDE.spritebuilder.SpotConfigScreen(
             toggle=toggler('spotcfg'),
-            data=json.loads(config['ELiDE']['place_graphics'])
-        )
+            data=json.loads(config['ELiDE']['place_graphics']))
 
-        self.statcfg = ELiDE.statcfg.StatScreen(
-            toggle=toggler('statcfg'),
-            engine=self.engine
-        )
+        self.statcfg = ELiDE.statcfg.StatScreen(toggle=toggler('statcfg'))
 
-        self.rules = ELiDE.rulesview.RulesScreen(
-            engine=self.engine,
-            toggle=toggler('rules')
-        )
+        self.rules = ELiDE.rulesview.RulesScreen(toggle=toggler('rules'))
 
         self.charrules = ELiDE.rulesview.CharacterRulesScreen(
-            engine=self.engine,
-            character=self.character,
-            toggle=toggler('charrules')
-        )
+            character=self.character, toggle=toggler('charrules'))
         self.bind(character=self.charrules.setter('character'))
 
-        self.chars = ELiDE.charsview.CharactersScreen(
-            engine=self.engine,
-            toggle=toggler('chars'),
-            new_board=self.new_board
-        )
+        self.chars = ELiDE.charsview.CharactersScreen(toggle=toggler('chars'),
+                                                      new_board=self.new_board)
         self.bind(character_name=self.chars.setter('character_name'))
 
         def chars_push_character_name(*args):
@@ -324,65 +310,50 @@ class ELiDEApp(App):
 
         self.chars.push_character_name = chars_push_character_name
 
-        self.strings = ELiDE.stores.StringsEdScreen(
-            toggle=toggler('strings')
-        )
+        self.strings = ELiDE.stores.StringsEdScreen(toggle=toggler('strings'))
 
-        self.funcs = ELiDE.stores.FuncsEdScreen(
-            name='funcs',
-            toggle=toggler('funcs')
-        )
+        self.funcs = ELiDE.stores.FuncsEdScreen(name='funcs',
+                                                toggle=toggler('funcs'))
 
-        self.bind(
-            selected_proxy=self.statcfg.setter('proxy')
-        )
+        self.bind(selected_proxy=self.statcfg.setter('proxy'))
 
         self.mainscreen = ELiDE.screen.MainScreen(
             use_kv=config['ELiDE']['user_kv'] == 'yes',
-            play_speed=int(config['ELiDE']['play_speed'])
-        )
+            play_speed=int(config['ELiDE']['play_speed']))
         if self.mainscreen.statlist:
             self.statcfg.statlist = self.mainscreen.statlist
         self.mainscreen.bind(statlist=self.statcfg.setter('statlist'))
-        self.bind(
-            selection=self.refresh_selected_proxy,
-            character=self.refresh_selected_proxy
-        )
-        for wid in (
-                self.mainmenu,
-                self.mainscreen,
-                self.pawncfg,
-                self.spotcfg,
-                self.statcfg,
-                self.rules,
-                self.charrules,
-                self.chars,
-                self.strings,
-                self.funcs
-        ):
+        self.bind(selection=self.refresh_selected_proxy,
+                  character=self.refresh_selected_proxy)
+        for wid in (self.mainmenu, self.mainscreen, self.pawncfg, self.spotcfg,
+                    self.statcfg, self.rules, self.charrules, self.chars,
+                    self.strings, self.funcs):
             self.manager.add_widget(wid)
         self.manager.current = 'mainmenu'
+        if (os.environ['KIVY_NO_ARGS']
+                or sys.argv[-2] == '-') and os.path.exists(
+                    sys.argv[-1]) and os.path.isdir(sys.argv[-1]):
+            self.mainmenu.open(os.path.abspath(sys.argv[-1]))
 
     def update_calendar(self, calendar, past_turns=1, future_turns=5):
         """Fill in a calendar widget with actual simulation data"""
         startturn = self.turn - past_turns
         endturn = self.turn + future_turns
         stats = ['_config'] + [
-            stat for stat in self.selected_proxy if not stat.startswith('_')
-            and stat not in ('character', 'name')
+            stat for stat in self.selected_proxy
+            if not stat.startswith('_') and stat not in ('character', 'name')
         ]
         if isinstance(self.selected_proxy, CharStatProxy):
             sched_entity = self.engine.character[self.selected_proxy.name]
         else:
             sched_entity = self.selected_proxy
         calendar.entity = sched_entity
-        calendar.from_schedule(
-            self.engine.handle(
-                'get_schedule', entity=sched_entity,
-                stats=stats, beginning=startturn, end=endturn
-            ),
-            start_turn=startturn
-        )
+        calendar.from_schedule(self.engine.handle('get_schedule',
+                                                  entity=sched_entity,
+                                                  stats=stats,
+                                                  beginning=startturn,
+                                                  end=endturn),
+                               start_turn=startturn)
 
     def _set_language(self, lang):
         self.engine.string.language = lang
@@ -392,10 +363,8 @@ class ELiDEApp(App):
             return self.character.stat
         elif hasattr(self.selection, 'proxy'):
             return self.selection.proxy
-        elif (
-                hasattr(self.selection, 'portal') and
-                self.selection.portal is not None
-        ):
+        elif (hasattr(self.selection, 'portal')
+              and self.selection.portal is not None):
             return self.selection.portal
         else:
             raise ValueError("Invalid selection: {}".format(self.selection))
@@ -407,18 +376,23 @@ class ELiDEApp(App):
         if not self.engine:
             Clock.schedule_once(self.on_character_name, 0)
             return
-        self.engine.eternal['boardchar'] = self.engine.character[self.character_name]
+        self.engine.eternal['boardchar'] = self.engine.character[
+            self.character_name]
 
     def on_character(self, *args):
         if not hasattr(self, 'mainscreen'):
             Clock.schedule_once(self.on_character, 0)
             return
         if hasattr(self, '_oldchar'):
-            self.mainscreen.graphboards[self._oldchar.name].unbind(selection=self.setter('selection'))
-            self.mainscreen.gridboards[self._oldchar.name].unbind(selection=self.setter('selection'))
+            self.mainscreen.graphboards[self._oldchar.name].unbind(
+                selection=self.setter('selection'))
+            self.mainscreen.gridboards[self._oldchar.name].unbind(
+                selection=self.setter('selection'))
         self.selection = None
-        self.mainscreen.graphboards[self.character.name].bind(selection=self.setter('selection'))
-        self.mainscreen.gridboards[self.character.name].bind(selection=self.setter('selection'))
+        self.mainscreen.graphboards[self.character.name].bind(
+            selection=self.setter('selection'))
+        self.mainscreen.gridboards[self.character.name].bind(
+            selection=self.setter('selection'))
 
     def on_pause(self):
         """Sync the database with the current state of the game."""
@@ -426,17 +400,18 @@ class ELiDEApp(App):
             self.engine.commit()
         self.strings.save()
         self.funcs.save()
-        self.config.write()
 
     def on_stop(self, *largs):
         """Sync the database, wrap up the game, and halt."""
+        self.mainmenu.closed = True
         self.strings.save()
         self.funcs.save()
         if self.engine:
             self.engine.commit()
         if hasattr(self, 'procman'):
             self.procman.shutdown()
-        self.config.write()
+        if hasattr(self, 'starting_dir'):
+            os.chdir(self.starting_dir)
 
     def delete_selection(self):
         """Delete both the selected widget and whatever it represents."""
@@ -444,16 +419,13 @@ class ELiDEApp(App):
         if selection is None:
             return
         if isinstance(selection, GraphArrowWidget):
-            if selection.reciprocal and selection.reciprocal.portal.get('is_mirror', False):
+            if selection.reciprocal and selection.reciprocal.portal.get(
+                    'is_mirror', False):
                 selection.reciprocal.portal.delete()
                 self.mainscreen.boardview.board.rm_arrow(
-                    selection.destination.name,
-                    selection.origin.name
-                )
+                    selection.destination.name, selection.origin.name)
             self.mainscreen.boardview.board.rm_arrow(
-                selection.origin.name,
-                selection.destination.name
-            )
+                selection.origin.name, selection.destination.name)
             selection.portal.delete()
         elif isinstance(selection, GraphSpot):
             charn = selection.board.character.name
@@ -476,3 +448,7 @@ class ELiDEApp(App):
         self.mainscreen.graphboards[name] = GraphBoard(character=char)
         self.mainscreen.gridboards[name] = GridBoard(character=char)
         self.character = char
+
+    def on_edit_locked(self, *args):
+        Logger.debug("ELiDEApp: " +
+                     ("edit locked" if self.edit_locked else "edit unlocked"))
