@@ -3,8 +3,7 @@
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# the Free Software Foundation, version 3.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +12,6 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
 """The big layout that you view all of ELiDE through.
 
 Handles touch, selection, and time control. Contains a graph, a stat
@@ -23,27 +21,22 @@ grid, the time control panel, and the menu.
 from functools import partial
 from ast import literal_eval
 
+from kivy.app import App
 from kivy.factory import Factory
 from kivy.lang import Builder
 from kivy.uix.togglebutton import ToggleButton
 from kivy.uix.button import Button
 from kivy.uix.boxlayout import BoxLayout
 from kivy.uix.floatlayout import FloatLayout
-from kivy.uix.modalview import ModalView
 from kivy.uix.scrollview import ScrollView
 from kivy.uix.screenmanager import Screen
 from kivy.clock import Clock
 from kivy.logger import Logger
-from kivy.properties import (
-    BooleanProperty,
-    BoundedNumericProperty,
-    DictProperty,
-    ListProperty,
-    NumericProperty,
-    ObjectProperty,
-    ReferenceListProperty,
-    StringProperty
-)
+from kivy.properties import (BooleanProperty, BoundedNumericProperty,
+                             DictProperty, ListProperty, NumericProperty,
+                             ObjectProperty, ReferenceListProperty,
+                             StringProperty)
+from .stepper import RuleStepper
 from .charmenu import CharMenu
 from .graph.board import GraphBoardView
 from .grid.board import GridBoardView
@@ -100,6 +93,10 @@ class SimulateButton(ToggleButton):
     graphics_bot = NumericProperty()
     graphics_center_y = NumericProperty()
 
+    def on_state(self, *args):
+        app = App.get_running_app()
+        app.edit_locked = self.state == 'down'
+
 
 class OneTurnButton(Button):
     graphics_top = NumericProperty()
@@ -110,6 +107,15 @@ class OneTurnButton(Button):
     step_bar_right = NumericProperty()
     step_arrow_points = ListProperty([0] * 6)
     step_rect_points = ListProperty([0] * 8)
+    screen = ObjectProperty()
+
+    def on_release(self):
+        App.get_running_app().edit_locked = True
+        self.screen.next_turn(cb=self._release_edit_lock)
+
+    @staticmethod
+    def _release_edit_lock(*args):
+        App.get_running_app().edit_locked = False
 
 
 class TimePanel(BoxLayout):
@@ -134,16 +140,19 @@ class TimePanel(BoxLayout):
         branch = self.ids.branchfield.text
         self.ids.branchfield.text = ''
         self.screen.app.branch = branch
+        self.screen.charmenu._switch_to_menu()
 
     def set_turn(self, *args):
         turn = int(self.ids.turnfield.text)
         self.ids.turnfield.text = ''
         self.screen.app.turn = turn
+        self.screen.charmenu._switch_to_menu()
 
     def set_tick(self, *args):
         tick = int(self.ids.tickfield.text)
         self.ids.tickfield.text = ''
         self.screen.app.tick = tick
+        self.screen.charmenu._switch_to_menu()
 
     def _upd_branch_hint(self, *args):
         self.ids.branchfield.hint_text = self.screen.app.branch
@@ -155,17 +164,16 @@ class TimePanel(BoxLayout):
         self.ids.tickfield.hint_text = str(self.screen.app.tick)
 
     def on_screen(self, *args):
-        if not all(field in self.ids for field in ('branchfield', 'turnfield', 'tickfield')):
+        if not all(field in self.ids
+                   for field in ('branchfield', 'turnfield', 'tickfield')):
             Clock.schedule_once(self.on_screen, 0)
             return
         self.ids.branchfield.hint_text = self.screen.app.branch
         self.ids.turnfield.hint_text = str(self.screen.app.turn)
         self.ids.tickfield.hint_text = str(self.screen.app.tick)
-        self.screen.app.bind(
-            branch=self._upd_branch_hint,
-            turn=self._upd_turn_hint,
-            tick=self._upd_tick_hint
-        )
+        self.screen.app.bind(branch=self._upd_branch_hint,
+                             turn=self._upd_turn_hint,
+                             tick=self._upd_tick_hint)
 
 
 class MainScreen(Screen):
@@ -200,11 +208,23 @@ class MainScreen(Screen):
     visible = BooleanProperty()
     _touch = ObjectProperty(None, allownone=True)
     rules_per_frame = BoundedNumericProperty(10, min=1)
-    app = ObjectProperty()
     tmp_block = BooleanProperty(False)
 
+    @property
+    def app(self):
+        return App.get_running_app()
+
+    def _update_adding_portal(self, *args):
+        self.boardview.adding_portal = self.charmenu.portaladdbut.state == 'down'
+
+    def _update_board(self, *args):
+        self.boardview.board = self.graphboards[self.app.character_name]
+        self.gridview.board = self.gridboards[self.app.character_name]
+
     def on_mainview(self, *args):
-        if None in (self.statpanel, self.charmenu, self.app) or None in (self.app.character_name, self.charmenu.portaladdbut):
+        if None in (self.statpanel, self.charmenu, self.app) or None in (
+                self.app.character_name, self.charmenu.portaladdbut
+        ) or self.app.character_name not in self.graphboards:
             Clock.schedule_once(self.on_mainview, 0)
             return
         self.boardview = GraphBoardView(
@@ -213,40 +233,26 @@ class MainScreen(Screen):
             size=self.mainview.size,
             pos=self.mainview.pos,
             board=self.graphboards[self.app.character_name],
-            adding_portal=self.charmenu.portaladdbut.state == 'down'
-        )
-        def update_adding_portal(*args):
-            self.boardview.adding_portal = self.charmenu.portaladdbut.state == 'down'
-        def update_board(*args):
-            self.boardview.board = self.graphboards[self.app.character_name]
-        self.mainview.bind(
-            size=self.boardview.setter('size'),
-            pos=self.boardview.setter('pos')
-        )
-        self.charmenu.portaladdbut.bind(state=update_adding_portal)
-        self.app.bind(character_name=update_board)
-        self.calendar = Agenda(
-            update_mode='present'
-        )
-        self.calendar_view = ScrollView(
-            size=self.mainview.size,
-            pos=self.mainview.pos
-        )
+            adding_portal=self.charmenu.portaladdbut.state == 'down')
+        self.mainview.bind(size=self.boardview.setter('size'),
+                           pos=self.boardview.setter('pos'))
+        self.charmenu.portaladdbut.bind(state=self._update_adding_portal)
+        self.app.bind(character_name=self._update_board)
+        self.calendar = Agenda(update_mode='present')
+        self.calendar_view = ScrollView(size=self.mainview.size,
+                                        pos=self.mainview.pos)
         self.gridview = GridBoardView(
             scale_min=0.2,
             scale_max=4.0,
             size=self.mainview.size,
             pos=self.mainview.pos,
-            board=self.gridboards[self.app.character_name]
-        )
+            board=self.gridboards[self.app.character_name])
         self.mainview.bind(
             size=self.calendar_view.setter('size'),
             pos=self.calendar_view.setter('pos'),
         )
-        self.mainview.bind(
-            size=self.gridview.setter('size'),
-            pos=self.gridview.setter('pos')
-        )
+        self.mainview.bind(size=self.gridview.setter('size'),
+                           pos=self.gridview.setter('pos'))
         self.calendar_view.add_widget(self.calendar)
         self.mainview.add_widget(self.boardview)
 
@@ -254,20 +260,21 @@ class MainScreen(Screen):
         if not self.app:
             Clock.schedule_once(self.on_statpanel, 0)
             return
-        self._update_statlist()
-        self.app.bind(
-            selected_proxy=self._update_statlist,
-            branch=self._update_statlist,
-            turn=self._update_statlist,
-            tick=self._update_statlist
-        )
+        self.app.bind(selected_proxy=self._update_statlist,
+                      branch=self._update_statlist,
+                      turn=self._update_statlist,
+                      tick=self._update_statlist)
 
     @trigger
     def _update_statlist(self, *args):
+        if not self.app or not self.app.engine:
+            return
         if not self.app.selected_proxy:
             self._update_statlist()
             return
-        self.app.update_calendar(self.statpanel.statlist, past_turns=0, future_turns=0)
+        self.app.update_calendar(self.statpanel.statlist,
+                                 past_turns=0,
+                                 future_turns=0)
 
     def pull_visibility(self, *args):
         self.visible = self.manager.current == 'main'
@@ -283,7 +290,8 @@ class MainScreen(Screen):
         """
         if hasattr(self, '_play_scheduled'):
             Clock.unschedule(self._play_scheduled)
-        self._play_scheduled = Clock.schedule_interval(self.play, 1.0 / self.play_speed)
+        self._play_scheduled = Clock.schedule_interval(self.play,
+                                                       1.0 / self.play_speed)
 
     def remake_display(self, *args):
         """Remake any affected widgets after a change in my ``kv``.
@@ -295,18 +303,14 @@ class MainScreen(Screen):
             del self._kv_layout
         self._kv_layout = KvLayout()
         self.add_widget(self._kv_layout)
+
     _trigger_remake_display = trigger(remake_display)
 
     def on_touch_down(self, touch):
         if self.visible:
             touch.grab(self)
-        for interceptor in (
-            self.timepanel,
-            self.charmenu,
-            self.statpanel,
-            self.dummyplace,
-            self.dummything
-        ):
+        for interceptor in (self.timepanel, self.charmenu, self.statpanel,
+                            self.dummyplace, self.dummything):
             if interceptor.collide_point(*touch.pos):
                 interceptor.dispatch('on_touch_down', touch)
                 self.boardview.keep_selection = \
@@ -334,6 +338,7 @@ class MainScreen(Screen):
         if not self.app.character:
             Clock.schedule_once(self.on_dummies, 0)
             return
+
         def renum_dummy(dummy, *args):
             dummy.num = dummynum(self.app.character, dummy.prefix) + 1
 
@@ -357,7 +362,8 @@ class MainScreen(Screen):
         # horrible hack
         self.dummyplace.paths = self.app.spotcfg.imgpaths
 
-    def _update_from_time_travel(self, command, branch, turn, tick, result, **kwargs):
+    def _update_from_time_travel(self, command, branch, turn, tick, result,
+                                 **kwargs):
         self._update_from_delta(command, branch, turn, tick, result[-1])
 
     def _update_from_delta(self, cmd, branch, turn, tick, delta, **kwargs):
@@ -365,13 +371,10 @@ class MainScreen(Screen):
         self.app.turn = turn
         self.app.tick = tick
         chardelta = delta.get(self.boardview.board.character.name, {})
-        for unwanted in (
-            'character_rulebook',
-            'avatar_rulebook',
-            'character_thing_rulebook',
-            'character_place_rulebook',
-            'character_portal_rulebook'
-        ):
+        for unwanted in ('character_rulebook', 'avatar_rulebook',
+                         'character_thing_rulebook',
+                         'character_place_rulebook',
+                         'character_portal_rulebook'):
             if unwanted in chardelta:
                 del chardelta[unwanted]
         self.boardview.board.trigger_update_from_delta(chardelta)
@@ -384,25 +387,32 @@ class MainScreen(Screen):
         If you want to disable this, set ``engine.universal['block'] = True``
 
         """
-        if self.playbut.state == 'normal':
+        if self.playbut.state == 'normal' or not hasattr(self.app, 'engine') or \
+                self.app.engine is None or self.app.engine.closed:
             return
         self.next_turn()
 
-    def _update_from_next_turn(self, command, branch, turn, tick, result):
+    def _update_from_next_turn(self,
+                               command,
+                               branch,
+                               turn,
+                               tick,
+                               result,
+                               cb=None):
         todo, deltas = result
         if isinstance(todo, list):
             self.dialoglayout.todo = todo
             self.dialoglayout.idx = 0
         self._update_from_delta(command, branch, turn, tick, deltas)
         self.dialoglayout.advance_dialog()
-        self.app.bind(
-            branch=self.app._push_time,
-            turn=self.app._push_time,
-            tick=self.app._push_time
-        )
+        self.app.bind(branch=self.app._push_time,
+                      turn=self.app._push_time,
+                      tick=self.app._push_time)
         self.tmp_block = False
+        if cb is not None:
+            cb(command, branch, turn, tick, result)
 
-    def next_turn(self, *args):
+    def next_turn(self, cb=None, *args):
         """Advance time by one turn, if it's not blocked.
 
         Block time by setting ``engine.universal['block'] = True``"""
@@ -411,18 +421,20 @@ class MainScreen(Screen):
         eng = self.app.engine
         dial = self.dialoglayout
         if eng.universal.get('block'):
-            Logger.info("MainScreen: next_turn blocked, delete universal['block'] to unblock")
+            Logger.info(
+                "MainScreen: next_turn blocked, delete universal['block'] to unblock"
+            )
             return
         if dial.idx < len(dial.todo):
-            Logger.info("MainScreen: not advancing time while there's a dialog")
+            Logger.info(
+                "MainScreen: not advancing time while there's a dialog")
             return
         self.tmp_block = True
-        self.app.unbind(
-            branch=self.app._push_time,
-            turn=self.app._push_time,
-            tick=self.app._push_time
-        )
-        eng.next_turn(cb=self._update_from_next_turn)
+        self.app.unbind(branch=self.app._push_time,
+                        turn=self.app._push_time,
+                        tick=self.app._push_time)
+        eng.next_turn(cb=partial(self._update_from_next_turn, cb=cb))
+        self.ids.charmenu._switch_to_menu()
 
     def switch_to_calendar(self, *args):
         self.app.update_calendar(self.calendar)
@@ -431,7 +443,8 @@ class MainScreen(Screen):
 
     def switch_to_boardview(self, *args):
         self.mainview.clear_widgets()
-        self.app.engine.handle('apply_choices', choices=[self.calendar.get_track()])
+        self.app.engine.handle('apply_choices',
+                               choices=[self.calendar.get_track()])
         self.mainview.add_widget(self.boardview)
 
     def toggle_gridview(self, *args):
@@ -450,8 +463,60 @@ class MainScreen(Screen):
             self.switch_to_boardview()
 
 
-Builder.load_string(
-    """
+class CharMenuContainer(BoxLayout):
+    screen = ObjectProperty()
+    dummyplace = ObjectProperty()
+    dummything = ObjectProperty()
+    portaladdbut = ObjectProperty()
+
+    def __init__(self, **kwargs):
+        super(CharMenuContainer, self).__init__(**kwargs)
+        self.charmenu = CharMenu(screen=self.screen, size_hint_y=0.9)
+        self.bind(screen=self.charmenu.setter('screen'))
+        self.dummyplace = self.charmenu.dummyplace
+        self.charmenu.bind(dummyplace=self.setter('dummyplace'))
+        self.dummything = self.charmenu.dummything
+        self.charmenu.bind(dummything=self.setter('dummything'))
+        self.portaladdbut = self.charmenu.portaladdbut
+        self.charmenu.bind(portaladdbut=self.setter('portaladdbut'))
+        self.stepper = RuleStepper(size_hint_y=0.9)
+        self.button = Button(on_release=self._toggle,
+                             text='Rule\nstepper',
+                             size_hint_y=0.1)
+
+    def on_parent(self, *args):
+        if not self.screen or not hasattr(self, 'charmenu') or not hasattr(
+                self, 'stepper') or not hasattr(self, 'button'):
+            Clock.schedule_once(self.on_parent, 0)
+            return
+        self.add_widget(self.charmenu)
+        self.add_widget(self.button)
+
+    @trigger
+    def _toggle(self, *args):
+        if self.charmenu in self.children:
+            engine = self.screen.app.engine
+            self.clear_widgets()
+            self.stepper.from_rules_handled_turn(
+                engine.handle('rules_handled_turn'))
+            self.add_widget(self.stepper)
+            self.button.text = 'Menu'
+        else:
+            self.clear_widgets()
+            self.add_widget(self.charmenu)
+            self.button.text = 'Rule stepper'
+        self.add_widget(self.button)
+
+    @trigger
+    def _switch_to_menu(self, *args):
+        if self.charmenu not in self.children:
+            self.clear_widgets()
+            self.add_widget(self.charmenu)
+            self.button.text = 'Rule stepper'
+            self.add_widget(self.button)
+
+
+Builder.load_string("""
 #: import resource_find kivy.resources.resource_find
 <StatListPanel>:
     orientation: 'vertical'
@@ -468,6 +533,7 @@ Builder.load_string(
         size_hint_y: 0.8
         entity: root.proxy
         update_mode: 'present'
+        disabled: app.edit_locked
     Button:
         id: gridviewbut
         size_hint_y: 0.05
@@ -562,11 +628,10 @@ Builder.load_string(
         OneTurnButton:
             id: stepbut
             font_size: root.buttons_font_size
-            on_release: root.screen.next_turn()
-            disabled: root.disable_one_turn
+            screen: root.screen
+            disabled: root.disable_one_turn or app.edit_locked
 <MainScreen>:
     name: 'main'
-    app: app
     dummyplace: charmenu.dummyplace
     dummything: charmenu.dummything
     mainview: mainview
@@ -599,8 +664,9 @@ Builder.load_string(
         pos_hint: {'bot': 0}
         size_hint: (0.25, 0.2)
         disable_one_turn: root.tmp_block
-    CharMenu:
+    CharMenuContainer:
         id: charmenu
+        orientation: 'vertical'
         screen: root
         pos_hint: {'right': 1, 'top': 1}
         size_hint: (0.1, 1)
@@ -612,5 +678,4 @@ Builder.load_string(
         y: timepanel.top
         width: charmenu.x - statpanel.right
         height: root.height - timepanel.top
-"""
-)
+""")
