@@ -3,8 +3,7 @@
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# the Free Software Foundation, version 3.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,6 +27,7 @@ from functools import partial
 from ast import parse
 from textwrap import indent, dedent
 
+from kivy.app import App
 from kivy.clock import Clock
 from kivy.lang import Builder
 from kivy.logger import Logger
@@ -38,14 +38,8 @@ from kivy.uix.textinput import TextInput
 from kivy.uix.recycleview.views import RecycleDataViewBehavior
 from kivy.uix.togglebutton import ToggleButton
 
-from kivy.properties import (
-    AliasProperty,
-    BooleanProperty,
-    ListProperty,
-    NumericProperty,
-    ObjectProperty,
-    StringProperty
-)
+from kivy.properties import (AliasProperty, BooleanProperty, ListProperty,
+                             NumericProperty, ObjectProperty, StringProperty)
 from .util import trigger
 
 
@@ -74,7 +68,6 @@ class StoreButton(RecycleToggleButton):
     """Text of this item"""
     select = ObjectProperty()
     """Function that gets called with my ``index`` when I'm selected"""
-
     def on_parent(self, *args):
         if self.name == '+':
             self.state = 'down'
@@ -96,7 +89,6 @@ class StoreList(RecycleView):
     """The ``name`` of the ``StoreButton`` currently selected"""
     boxl = ObjectProperty()
     """Instance of ``SelectableRecycleBoxLayout``"""
-
     def __init__(self, **kwargs):
         self._i2name = {}
         self._name2i = {}
@@ -161,7 +153,6 @@ class LanguageInput(TextInput):
     """Widget to enter the language you want to edit"""
     screen = ObjectProperty()
     """The instance of ``StringsEdScreen`` that I'm in"""
-
     def on_focus(self, instance, value, *largs):
         if not value:
             if self.screen.language != self.text:
@@ -183,9 +174,6 @@ class StringsEdScreen(Screen):
     """Code identifying the language we're editing"""
     edbox = ObjectProperty()
     """Widget containing editors for the current string and its name"""
-    store = ObjectProperty()
-    """The string store, an attribute of the LiSE engine"""
-
     def on_language(self, *args):
         if self.edbox is None:
             Clock.schedule_once(self.on_language, 0)
@@ -193,11 +181,11 @@ class StringsEdScreen(Screen):
         self.edbox.storelist.redata()
         if self.store.language != self.language:
             self.store.language = self.language
-    
+
     def on_store(self, *args):
         self.language = self.store.language
         self.store.language.connect(self._pull_language)
-    
+
     def _pull_language(self, *args, language):
         self.language = language
 
@@ -223,43 +211,41 @@ class Editor(BoxLayout):
     def save(self, *args):
         """Put text in my store, return True if it changed"""
         if self.name_wid is None or self.store is None:
-            Logger.debug("{}: Not saving, missing name_wid or store".format(type(self).__name__))
+            Logger.debug("{}: Not saving, missing name_wid or store".format(
+                type(self).__name__))
             return
         if not (self.name_wid.text or self.name_wid.hint_text):
             Logger.debug("{}: Not saving, no name".format(type(self).__name__))
             return
-        if self.name_wid.text and self.name_wid.text[0] in string.digits + string.whitespace + string.punctuation:
+        if self.name_wid.text and self.name_wid.text[
+                0] in string.digits + string.whitespace + string.punctuation:
             # TODO alert the user to invalid name
-            Logger.warning("{}: Not saving, invalid name".format(type(self).__name__))
+            Logger.warning("{}: Not saving, invalid name".format(
+                type(self).__name__))
             return
         if hasattr(self, '_do_parse'):
             try:
                 parse(self.source)
             except SyntaxError:
                 # TODO alert user to invalid source
-                Logger.debug("{}: Not saving, couldn't parse".format(type(self).__name__))
+                Logger.debug("{}: Not saving, couldn't parse".format(
+                    type(self).__name__))
                 return
         do_redata = False
         if self.name_wid.text:
-            if (
-                self.name_wid.hint_text and
-                self.name_wid.hint_text != self.name_wid.text and
-                hasattr(self.store, self.name_wid.hint_text)
-            ):
+            if (self.name_wid.hint_text
+                    and self.name_wid.hint_text != self.name_wid.text
+                    and hasattr(self.store, self.name_wid.hint_text)):
                 delattr(self.store, self.name_wid.hint_text)
                 do_redata = True
-            if (
-                not hasattr(self.store, self.name_wid.text) or
-                getattr(self.store, self.name_wid.text) != self.source
-            ):
+            if (not hasattr(self.store, self.name_wid.text)
+                    or getattr(self.store, self.name_wid.text) != self.source):
                 Logger.debug("{}: Saving!".format(type(self).__name__))
                 setattr(self.store, self.name_wid.text, self.source)
                 do_redata = True
         elif self.name_wid.hint_text:
-            if (
-                not hasattr(self.store, self.name_wid.hint_text) or
-                getattr(self.store, self.name_wid.hint_text) != self.source
-            ):
+            if (not hasattr(self.store, self.name_wid.hint_text) or getattr(
+                    self.store, self.name_wid.hint_text) != self.source):
                 Logger.debug("{}: Saving!".format(type(self).__name__))
                 setattr(self.store, self.name_wid.hint_text, self.source)
                 do_redata = True
@@ -282,7 +268,6 @@ class StringInput(Editor):
     """Editor for human-readable strings"""
     validate_name_input = ObjectProperty()
     """Boolean function for checking if a string name is acceptable"""
-
     def on_name_wid(self, *args):
         if not self.validate_name_input:
             Clock.schedule_once(self.on_name_wid, 0)
@@ -327,33 +312,45 @@ class EdBox(BoxLayout):
     """An instance of a subclass of ``Editor``"""
     store = ObjectProperty()
     """Proxy to the store I represent"""
+    store_name = StringProperty()
+    """Name of my store, so I can get it from the engine"""
     data = ListProperty()
     """Dictionaries describing widgets in my ``storelist``"""
     toggle = ObjectProperty()
     """Function to show or hide my screen"""
     disable_text_input = BooleanProperty(False)
     """Set to ``True`` to prevent entering text in the editor"""
+    def on_store_name(self, *args):
+        app = App.get_running_app()
+        if app.engine is None:
+            Clock.schedule_once(self.on_store_name, 0)
+            return
+        self.store = getattr(app.engine, self.store_name)
 
     def on_storelist(self, *args):
         self.storelist.bind(selection_name=self._pull_from_storelist)
 
     @trigger
     def validate_name_input(self, *args):
-        self.disable_text_input = not (self.valid_name(self.editor.name_wid.hint_text) or self.valid_name(self.editor.name_wid.text))
+        self.disable_text_input = not (
+            self.valid_name(self.editor.name_wid.hint_text)
+            or self.valid_name(self.editor.name_wid.text))
 
     @trigger
     def _pull_from_storelist(self, *args):
         self.save()
         # The + button at the top is for adding an entry yet unnamed, so don't display hint text for it
-        self.editor.name_wid.hint_text = self.storelist.selection_name.strip('+')
+        self.editor.name_wid.hint_text = self.storelist.selection_name.strip(
+            '+')
         self.editor.name_wid.text = ''
         try:
-            self.editor.source = getattr(
-                self.store, self.editor.name_wid.hint_text
-            )
+            self.editor.source = getattr(self.store,
+                                         self.editor.name_wid.hint_text)
         except AttributeError:
-            self.editor.source = self.get_default_text(self.editor.name_wid.hint_text)
-        self.disable_text_input = not self.valid_name(self.editor.name_wid.hint_text)
+            self.editor.source = self.get_default_text(
+                self.editor.name_wid.hint_text)
+        self.disable_text_input = not self.valid_name(
+            self.editor.name_wid.hint_text)
         if hasattr(self, '_lock_save'):
             del self._lock_save
 
@@ -389,6 +386,7 @@ class EdBox(BoxLayout):
             self.storelist.redata(del_select)
         else:
             del self._lock_save
+
     _trigger_delete = trigger(delete)
 
     def on_store(self, *args):
@@ -413,7 +411,6 @@ class StringsEdBox(EdBox):
     """
     language = StringProperty('eng')
 
-
     @staticmethod
     def get_default_text(newname):
         return ''
@@ -438,9 +435,8 @@ class FunctionNameInput(TextInput):
         if self.text == '':
             if s[0] not in (string.ascii_letters + '_'):
                 return
-        return super().insert_text(
-            ''.join(c for c in s if c in (string.ascii_letters + string.digits + '_'))
-        )
+        return super().insert_text(''.join(
+            c for c in s if c in (string.ascii_letters + string.digits + '_')))
 
     def on_focus(self, inst, val, *largs):
         if not val:
@@ -458,10 +454,8 @@ def munge_source(v):
         firstline = lines[0].lstrip()
     if not lines:
         return tuple(), ''
-    params = tuple(
-        parm.strip() for parm in
-        sig_ex.match(lines[0]).group(1).split(',')
-    )
+    params = tuple(parm.strip()
+                   for parm in sig_ex.match(lines[0]).group(1).split(','))
     del lines[0]
     if not lines:
         return params, ''
@@ -486,7 +480,8 @@ class FuncEditor(Editor):
     _do_parse = True
 
     def _get_source(self):
-        code = self.get_default_text(self.name_wid.text or self.name_wid.hint_text)
+        code = self.get_default_text(self.name_wid.text
+                                     or self.name_wid.hint_text)
         if self._text:
             code += indent(self._text, ' ' * 4)
         else:
@@ -520,13 +515,13 @@ class FuncsEdBox(EdBox):
     FuncEditor showing the source of the selected one, and a close button.
 
     """
-
     def get_default_text(self, newname):
         return self.editor.get_default_text(newname)
 
     @staticmethod
     def valid_name(name):
-        return name and name[0] not in string.digits + string.whitespace + string.punctuation
+        return name and name[
+            0] not in string.digits + string.whitespace + string.punctuation
 
 
 class FuncsEdScreen(Screen):
@@ -605,7 +600,7 @@ Builder.load_string("""
         StringsEdBox:
             id: edbox
             toggle: root.toggle
-            store: root.store
+            store_name: 'string'
             language: root.language
         BoxLayout:
             size_hint_y: 0.05
@@ -720,7 +715,7 @@ Builder.load_string("""
             FuncsEdBox:
                 id: triggers
                 toggle: root.toggle
-                store: app.engine.trigger if app.engine else None
+                store_name: 'trigger'
                 on_data: app.rules.rulesview.set_functions('trigger', map(app.rules.rulesview.inspect_func, self.data))
         TabbedPanelItem:
             id: prereq
@@ -729,7 +724,7 @@ Builder.load_string("""
             FuncsEdBox:
                 id: prereqs
                 toggle: root.toggle
-                store: app.engine.prereq if app.engine else None
+                store_name: 'prereq'
                 on_data: app.rules.rulesview.set_functions('prereq', map(app.rules.rulesview.inspect_func, self.data))
         TabbedPanelItem:
             id: action
@@ -738,6 +733,6 @@ Builder.load_string("""
             FuncsEdBox:
                 id: actions
                 toggle: root.toggle
-                store: app.engine.action if app.engine else None
+                store_name: 'action'
                 on_data: app.rules.rulesview.set_functions('action', map(app.rules.rulesview.inspect_func, self.data))
 """)
